// java wrapper for vtkContourValues object
//

package vtk;
import vtk.*;

public class vtkContourValues extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetValue_2(int id0,double id1);
  public void SetValue(int id0,double id1)
    { SetValue_2(id0,id1); }

  private native double GetValue_3(int id0);
  public double GetValue(int id0)
    { return GetValue_3(id0); }

  private native void SetNumberOfContours_4(int id0);
  public void SetNumberOfContours(int id0)
    { SetNumberOfContours_4(id0); }

  private native int GetNumberOfContours_5();
  public int GetNumberOfContours()
    { return GetNumberOfContours_5(); }

  private native void GenerateValues_6(int id0,double id1[]);
  public void GenerateValues(int id0,double id1[])
    { GenerateValues_6(id0,id1); }

  private native void GenerateValues_7(int id0,double id1,double id2);
  public void GenerateValues(int id0,double id1,double id2)
    { GenerateValues_7(id0,id1,id2); }

  private native void DeepCopy_8(vtkContourValues id0);
  public void DeepCopy(vtkContourValues id0)
    { DeepCopy_8(id0); }

  public vtkContourValues() { super(); }

  public vtkContourValues(long id) { super(id); }
  public native long   VTKInit();

}
